@@ -13,19 +13,16 @@ def AveDevCalTab(x_list,y_list):
                 dev.append(ave_dev)
         DEV.append(dev)
     print("均差计算表如下:")
-    print("+---------------------------------------------------------------------+")
     print("|{:^9}|{:^9}".format("X","Y"),end="|")
     for i in range(1,N):
-        print("{:^9}".format(str(i)+"阶"),end="")
+        print("{:^9}|".format("N"+str(i)),end="")
     print("")
-    print("+---------------------------------------------------------------------+")
     for i in range(N):
         print("|",end="")
         print("{:^9.5f}".format(x_list[i]),end="|")
         for j in range(N):
             print("{:^9.5f}".format(DEV[j][i]),end="|")
         print("")
-        print("+---------------------------------------------------------------------+")
 
 def NewtonChaZHi(x_list,y_list,x):
     DEV=[]
@@ -51,3 +48,6 @@ def NewtonChaZHi(x_list,y_list,x):
     return y
 
 
+x_list=[0,1,2,3,]
+y_list=[0,1,8,27]
+AveDevCalTab(x_list,y_list)
